@@ -43,7 +43,7 @@ class ShowMember(quantumv20.ShowCommand):
 
 
 class CreateMember(quantumv20.CreateCommand):
-    """Create a member"""
+    """Create a member."""
 
     resource = 'member'
     log = logging.getLogger(__name__ + '.CreateMember')
@@ -52,22 +52,22 @@ class CreateMember(quantumv20.CreateCommand):
         parser.add_argument(
             'pool_id', metavar='pool',
             help='Pool id or name this vip belongs to')
+        parser.add_argument(
+            '--admin-state-down',
+            dest='admin_state', action='store_false',
+            help='set admin state up to false')
+        parser.add_argument(
+            '--weight',
+            help='weight of pool member in the pool')
         parser.add_argument(
             '--address',
             required=True,
             help='IP address of the pool member on the pool network. ')
-        parser.add_argument(
-            '--admin-state-down',
-            default=True, action='store_false',
-            help='set admin state up to false')
         parser.add_argument(
             '--protocol-port',
             required=True,
             help='port on which the pool member listens for requests or '
                  'connections. ')
-        parser.add_argument(
-            '--weight',
-            help='weight of pool member in the pool')
 
     def args2body(self, parsed_args):
         _pool_id = quantumv20.find_resourceid_by_name_or_id(
@@ -75,7 +75,7 @@ class CreateMember(quantumv20.CreateCommand):
         body = {
             self.resource: {
                 'pool_id': _pool_id,
-                'admin_state_up': parsed_args.admin_state_down,
+                'admin_state_up': parsed_args.admin_state,
             },
         }
         quantumv20.update_dict(
