@@ -31,6 +31,7 @@ from cliff.commandmanager import CommandManager
 from quantumclient.common import clientmanager
 from quantumclient.common import exceptions as exc
 from quantumclient.common import utils
+from quantumclient.openstack.common import strutils
 
 
 VERSION = '2.0'
@@ -149,6 +150,8 @@ COMMAND_V2 = {
         'quantumclient.quantum.v2_0.securitygroup.CreateSecurityGroup'),
     'security-group-delete': utils.import_class(
         'quantumclient.quantum.v2_0.securitygroup.DeleteSecurityGroup'),
+    'security-group-update': utils.import_class(
+        'quantumclient.quantum.v2_0.securitygroup.UpdateSecurityGroup'),
     'security-group-rule-list': utils.import_class(
         'quantumclient.quantum.v2_0.securitygroup.ListSecurityGroupRule'),
     'security-group-rule-show': utils.import_class(
@@ -404,6 +407,11 @@ class QuantumShell(App):
             '--os_token',
             help=argparse.SUPPRESS)
 
+        parser.add_argument(
+            '--endpoint-type', metavar='<endpoint-type>',
+            default=env('OS_ENDPOINT_TYPE', default='publicURL'),
+            help='Defaults to env[OS_ENDPOINT_TYPE] or publicURL.')
+
         parser.add_argument(
             '--os-url', metavar='<url>',
             default=env('OS_URL'),
@@ -476,10 +484,10 @@ class QuantumShell(App):
             self.initialize_app(remainder)
         except Exception as err:
             if self.options.debug:
-                self.log.exception(err)
+                self.log.exception(unicode(err))
                 raise
             else:
-                self.log.error(err)
+                self.log.error(unicode(err))
             return 1
         result = 1
         if self.interactive_mode:
@@ -506,16 +514,16 @@ class QuantumShell(App):
             return run_command(cmd, cmd_parser, sub_argv)
         except Exception as err:
             if self.options.debug:
-                self.log.exception(err)
+                self.log.exception(unicode(err))
             else:
-                self.log.error(err)
+                self.log.error(unicode(err))
             try:
                 self.clean_up(cmd, result, err)
             except Exception as err2:
                 if self.options.debug:
-                    self.log.exception(err2)
+                    self.log.exception(unicode(err2))
                 else:
-                    self.log.error('Could not clean up: %s', err2)
+                    self.log.error('Could not clean up: %s', unicode(err2))
             if self.options.debug:
                 raise
         else:
@@ -523,9 +531,9 @@ class QuantumShell(App):
                 self.clean_up(cmd, result, None)
             except Exception as err3:
                 if self.options.debug:
-                    self.log.exception(err3)
+                    self.log.exception(unicode(err3))
                 else:
-                    self.log.error('Could not clean up: %s', err3)
+                    self.log.error('Could not clean up: %s', unicode(err3))
         return result
 
     def authenticate_user(self):
@@ -582,6 +590,7 @@ class QuantumShell(App):
             region_name=self.options.os_region_name,
             api_version=self.api_version,
             auth_strategy=self.options.os_auth_strategy,
+            endpoint_type=self.options.endpoint_type,
             insecure=self.options.insecure, )
         return
 
@@ -608,7 +617,7 @@ class QuantumShell(App):
     def clean_up(self, cmd, result, err):
         self.log.debug('clean_up %s', cmd.__class__.__name__)
         if err:
-            self.log.debug('got an error: %s', err)
+            self.log.debug('got an error: %s', unicode(err))
 
     def configure_logging(self):
         """Create logging handlers for any log output.
@@ -637,11 +646,12 @@ class QuantumShell(App):
 def main(argv=sys.argv[1:]):
     gettext.install('quantumclient', unicode=1)
     try:
-        return QuantumShell(QUANTUM_API_VERSION).run(argv)
+        return QuantumShell(QUANTUM_API_VERSION).run(map(strutils.safe_decode,
+                                                         argv))
     except exc.QuantumClientException:
         return 1
     except Exception as e:
-        print e
+        print unicode(e)
         return 1
 
 
